TRITON-MODEL-ANALYZER
=====================

**WARNING:** This project is not functional and is a placeholder from NVIDIA.
Please refer to https://github.com/triton-inference-server for additional information.

.. code-block:: bash

    pip install nvidia-pyindex
    pip install triton-model-analyzer